import { NOOP } from '@vue/shared';
import '../../components/index.mjs';
import { useGlobalConfig } from '../../components/config-provider/src/hooks/use-global-config.mjs';

const useSameTarget = (handleClick) => {
  const forEditor = useGlobalConfig("forEditor");
  if (forEditor.value || !handleClick) {
    return { onClick: NOOP, onMousedown: NOOP, onMouseup: NOOP };
  }
  let mousedownTarget = false;
  let mouseupTarget = false;
  const onClick = (e) => {
    if (mousedownTarget && mouseupTarget) {
      handleClick(e);
    }
    mousedownTarget = mouseupTarget = false;
  };
  const onMousedown = (e) => {
    mousedownTarget = e.target === e.currentTarget;
  };
  const onMouseup = (e) => {
    mouseupTarget = e.target === e.currentTarget;
  };
  return { onClick, onMousedown, onMouseup };
};

export { useSameTarget };
//# sourceMappingURL=index.mjs.map
